Cocaine-tools [![Build Status](https://travis-ci.org/cocaine/cocaine-tools.png?branch=master)](https://travis-ci.org/cocaine/cocaine-tools)[![Code Health](https://landscape.io/github/cocaine/cocaine-tools/master/landscape.png)](https://landscape.io/github/cocaine/cocaine-tools/master)
=============
Have you heard about Cocaine? No? Omg, you need to check its [repository](https://github.com/cocaine/cocaine-core) first.
You have? Okay, let's describe what me mean behind *cocaine-tools*.

It is command-line tools for simplifying application deployment, managing and monitoring. More you can read from
our official [documentation](http://cocaine-tools.readthedocs.org/en/latest).

* Page on github: https://github.com/cocaine
* Repository: https://github.com/cocaine/cocaine-framework-python
* Requires at least Python 2.6
